bayespy.inference.vmp.nodes.gaussian.WrapToGaussianGammaARD.__init__
====================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: WrapToGaussianGammaARD.__init__